@@ -26,6 +26,7 @@ __all__ = (
     "QueryObjectsPaginatorName",
     "TaskStatusType",
     "ServiceName",
+    "PaginatorName",
 )
 
 
@@ -315,3 +316,4 @@ ServiceName = Literal[
     "workspaces",
     "xray",
 ]
+PaginatorName = Literal["describe_objects", "list_pipelines", "query_objects"]
